// Package kutils нужен как ни странно для работы с кафкой. Работает пакет на основе паттерна "цепочка обязанностей".
//Альтернативная идея реализации: можно сделать синглтон через map в виде topic(ключ) - Writer (значение)
//и держать соединения открытыми.
//В таком случае нужно добавить waitGroup при отправке сообщений, так как наши соединения будут критическими ресурсами
package kutils

import (
	"github.com/Shopify/sarama"
	"log"
)

//KafkaCtx это структура для работы цепочки функций
//Поля должны быть локальными и меняться в функциях
//Цепь имеет вид конечного автомата
type KafkaCtx struct {
	w			sarama.SyncProducer
	r			sarama.ConsumerGroup
	key			string
	value		interface{}
	//поле connection можно и убрать, но лишним оно не будет как по мне
	connection	struct{
		topic	string
		host	string
	}
	sslConf		*sarama.Config
	Error		error
}

type KutilMessage struct {
	Method	string `json:"method"`
	Body	interface{} `json:"body"`
}

//Общие функции

func InitKafka() *KafkaCtx {
	return &KafkaCtx{}
}

func (ctx *KafkaCtx) SetConnection(topic string, host string) *KafkaCtx {
	if ctx.Error != nil {
		return ctx
	}
	ctx.connection.topic = topic
	ctx.connection.host = host
	return ctx
}

func (ctx *KafkaCtx) SetCertLogger(log *log.Logger) *KafkaCtx {
	if ctx.Error != nil {
		return ctx
	}
	sarama.Logger = log
	return ctx
}